#
# spec file for package janet
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global somajor 1
%global sominor 37
%global revision 1
%global libname libjanet%{somajor}_%{sominor}

Name:           janet
Version:        %{somajor}.%{sominor}.%{revision}
Release:        1.2
Summary:        Lisp-like functional and imperative programming language
License:        MIT
URL:            https://janet-lang.org
Source0:        https://github.com/janet-lang/janet/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  meson
BuildRequires:  ninja

%description
Janet is a functional and imperative programming language.  The entire
language (core library, interpreter, compiler, assembler, PEG) is less
than 2MB.  Janet scripting can be added to an application by embedding a
single C source file and a single header.

%package -n %{libname}
Summary:        Library for the lisp-like functional and imperative programming language
Group:          System/Libraries

%description -n %{libname}
This contains the library for Janet—a functional and imperative programming language.

%package devel
Summary:        Headers for embedding Janet scripting
Group:          Development/Languages/C and C++
Requires:       %{libname} = %{version}

%description devel
Janet is a functional and imperative programming language.  Janet scripting
can be added to an application by embedding a single C source file and a
single header.

This package contains the development files for the Janet programming language.

%package devel-static
Summary:        Headers for embedding Janet scripting
Group:          Development/Languages/C and C++
Requires:       %{libname} = %{version}
Requires:       %{name}-devel = %{version}

%description devel-static
Janet is a functional and imperative programming language.  Janet scripting
can be added to an application by embedding a single C source file and a
single header.

This package contains the development files for the Janet programming language.
It contains static libraries for -static linking which is highly discouraged.

%prep
%autosetup

%build
export CFLAGS="%optflags -ffat-lto-objects"
%meson -Ddefault_library=both
%meson_build

%install
export CFLAGS="%optflags -ffat-lto-objects"
%meson_install

# Remove useless keep file
rm %{buildroot}%{_libdir}/janet/.keep

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files
%{_bindir}/janet
%dir %{_libdir}/janet/
%{_mandir}/man1/janet.1%{?ext_man}
%license LICENSE
%doc *.md

%files devel
%dir %{_libdir}/janet
%dir %{_includedir}/janet

%if 0%{?suse_version} > 1600 || 0%{?sle_version} == 150500 && 0%{?is_opensuse}
%{_includedir}/janet.h
%endif

%{_includedir}/janet/*
%{_libdir}/pkgconfig/janet.pc
%{_libdir}/libjanet.so

%files devel-static
%{_libdir}/libjanet.a

%files -n %{libname}
%{_libdir}/lib%{name}.so.%{somajor}*

%changelog
* Sun Dec 15 2024 Soc Virnyl Estela <uncomfyhalomacro@opensuse.org>
- Update to version 1.37.1:
  * Fix meson cross compilation
  * Update timeout documentation for networking APIs: timeouts raise errors and do not return nil.
  * Add janet_addtimeout_nil(double sec); to the C API.
  * Change string hashing.
  * Fix string equality bug.
  * Add assertf
  * Change how JANET_PROFILE is loaded to allow more easily customizing the environment.
  * Add *repl-prompt* dynamic binding to allow customizing the built in repl.
  * Add multiple path support in the JANET_PATH environment variables. This lets user more easily import modules from many directories.
  * Add nth and only-tags PEG specials to select from sub-captures while dropping the rest.
* Tue Sep 10 2024 Soc Virnyl Estela <obs@uncomfyhalomacro.pl>
- Update to version 1.36.0:
  * Improve error messages in bundle/add* functions.
  * Add CI testing and verify tests pass on the s390x architecture.
  * Save :source-form in environment entries when *debug* is set.
  * Add experimental filewatch/ module for listening to file system changes on Linux and Windows.
  * Add bundle/who-is to query which bundle a file on disk was installed by.
  * Add geomean function
  * Add :R and :W flags to os/pipe to create blocking pipes on Posix and Windows systems. These streams cannot be directly read to and written from, but can be passed to subprocesses.
  * Add array/join
  * Add tuple/join
  * Add bundle/add-bin to make installing scripts easier. This also establishes a packaging convention for it.
  * Fix marshalling weak tables and weak arrays.
  * Fix bug in ev/ module that could accidentally close sockets on accident.
  * Expose C functions for constructing weak tables in janet.h
  * Let range take non-integer values.
* Tue Jun 25 2024 Soc Virnyl Estela <obs@uncomfyhalomacro.pl>
- Update to version 1.35.2
  * Fix some documentation typos.
  * Allow using :only in import without quoting.
* Sat Jun 15 2024 Soc Virnyl Estela <obs@uncomfyhalomacro.pl>
- Update to version 1.35.0
  * Add :only argument to import to allow for easier control over imported bindings.
  * Add extra optional env argument to eval and eval-string.
  * Allow naming function literals with a keyword. This allows better stacktraces for macros without
  * accidentally adding new bindings.
  * Add bundle/ module for managing packages within Janet. This should replace the jpm packaging
  * format eventually and is much simpler and amenable to more complicated builds.
  * Add macros ev/with-lock, ev/with-rlock, and ev/with-wlock for using mutexes and rwlocks.
  * Add with-env
  * Add *module-make-env*dynamic binding
  * Add buffer/format-at
  * Add long form command line options for readable CLI usage
  * Fix bug with net/accept-loop that would sometimes miss connections.
  * Build janet with Cosmopolitan Libc
  * Add ffi/defbind-alias
  * Add LoongArch64 suppor
  * Fix buffer push uint max
* Tue May 21 2024 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to version 1.34.0:
  * Add a new (split) PEG special
  * Add buffer/push-* sized int and float
  * Documentation improvements
  * Expose _exit to skip certain cleanup with os/exit.
  * Swap set / body order for each.
  * Abort on assert failure instead of exit.
  * Fix: os/proc-wait.
  * Fix macex1 to keep syntax location for all tuples.
  * Restore if-let tail calls.
  * Don't try and resume fibers that can't be resumed.
  * Register stream on unmarshal.
  * Fix asm roundtrip issue.
* Wed Jan 10 2024 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to version 1.33.0:
  * Add more + and * keywords to default-peg-grammar
  * Use libc strlen in janet_buffer_push_cstring
  * net/ev: Cleaned up unused NetStateConnect, fixed janet_async_end() ev refcount
  * fix (doc next)
  * Fix arity typo in peg
  * Cosmetically tweak string/format docstring
  * Add a new (sub) PEG special
* Fri Nov  3 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to version 1.32.1:
  * Report line and column when using janet_dobytes
  * Add :unless loop modifier
  * Allow calling reverse on generators.
  * Improve performance of a number of core functions including partition, mean, keys, values, pairs, interleave.
  * Add lengthable?
  * Add os/sigaction
  * Change every? and any? to behave like the functional versions of the and and or macros.
  * Fix bug with garbage collecting threaded abstract types.
  * Add :signal to the sandbox function to allow intercepting signals.
  * Fix return value from C function janet_dobytes when called on Janet functions that yield to event loop.
  * Change C API for event loop interaction - get rid of JanetListener and instead use janet_async_start and janet_async_end.
  * Rework event loop to make fewer system calls on kqueue and epoll.
  * Expose atomic refcount abstraction in janet.h
  * Add array/weak for weak references in arrays
  * Add support for weak tables via table/weak, table/weak-keys, and table/weak-values.
  * Fix compiler bug with using the result of (break x) expression in some contexts.
  * Rework internal event loop code to be better behaved on Windows
* Fri Nov  3 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Properly create subpackage for janet-devel-static
* Fri Nov  3 2023 Jochen Breuer <brejoc@gmail.com>
- Building static libjanet in addition to dynamic libjanet
  * This change enables building static binaries with jpm
* Sat Sep 30 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to version 1.31.0:
  * Report line and column when using `janet_dobytes`
  * Add `:unless` loop modifier
  * Allow calling `reverse` on generators.
  * Improve performance of a number of core functions including `partition`, `mean`, `keys`, `values`, `pairs`, `interleave`.
  * Add `lengthable?`
  * Add `os/sigaction`
  * Change `every?` and `any?` to behave like the functional versions of the `and` and `or` macros.
  * Fix bug with garbage collecting threaded abstract types.
  * Add `:signal` to the `sandbox` function to allow intercepting signals.
* Sat Aug 26 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 1.30.0:
  Changes in 1.30.0:
  - Change indexing of `array/remove` to start from -1 at the end instead of -2.
  - Add new string escape sequences `\\a`, `\\b`, `\\?`, and `\\'`.
  - Fix bug with marshalling channels
  - Add `div` for floored division
  - Make `div` and `mod` variadic
  - Support `bnot` for integer types.
  - Define `(mod x 0)` as `x`
  - Add `ffi/pointer-cfunction` to convert pointers to cfunctions
  Changes since 1.29.1:
  - Add support for passing booleans to PEGs for "always" and "never" matching.
  - Allow dictionary types for `take` and `drop`
  - Fix bug with closing channels while other fibers were waiting on them - `ev/take`, `ev/give`, and `ev/select`  will now return the correct (documented) value when another fiber closes the channel.
  - Add `ffi/calling-conventions` to show all available calling conventions for FFI.
  - Add `net/setsockopt`
  - Add `signal` argument to `os/proc-kill` to send signals besides `SIGKILL` on Posix.
  - Add `source` argument to `os/clock` to get different time sources.
  - Various combinator functions now are variadic like `map`
  - Add `file/lines` to iterate over lines in a file lazily.
  - Reorganize test suite to be sorted by module rather than pseudo-randomly.
  - Add `*task-id*`
  - Add `env` argument to `fiber/new`.
  - Add `JANET_NO_AMALG` flag to Makefile to properly incremental builds
  - Optimize bytecode compiler to generate fewer instructions and improve loops.
  - Fix bug with `ev/gather` and hung fibers.
  - Add `os/isatty`
  - Add `has-key?` and `has-value?`
  - Make imperative arithmetic macros variadic
  - `ev/connect` now yields to the event loop instead of blocking while waiting for an ACK.
* Mon May 29 2023 Jan Engelhardt <jengelh@inai.de>
- Fix errors, trim, and wrap description.
* Sat May 27 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 1.28.0:
  * Various bug fixes
  * Make nested short-fn's behave a bit more predictably (it is still not recommended to nest short-fns).
  * Add os/strftime for date formatting.
  * Fix ev/select on threaded channels sometimes live-locking.
  * Support the NO_COLOR environment variable to turn off VT100 color codes in repl (and in scripts).
  * See http://no-color.org/
  * Disallow using (splice x) in contexts where it doesn't make sense rather than silently coercing to x.
  * Instead, raise a compiler error.
  * Change the names of :user8 and :user9 sigals to :interrupt and :await
  * Change the names of :user8 and :user9 fiber statuses to :interrupted and :suspended.
  * Add ev/all-tasks to see all currently suspended fibers.
  * Add keep-syntax and keep-syntax! functions to make writing macros easier.
* Sat Mar  4 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Initial spec for janet 1.26.0
